@@ -43,27 +43,18 @@ WIN32DLL_DEFINE char *mcrypt_readdir(DIR * dirstream)
 	struct dirent ret2[sizeof(struct dirent)+MAXPATHLEN];
 #endif
 
-#ifdef DT_REG
-	do {
-#endif
-
 #ifdef HAVE_READDIR_R
-		readdir_r(dirstream, ret2, &ret);
+	readdir_r(dirstream, ret2, &ret);
 #else
-		ret = readdir(dirstream);
+	ret = readdir(dirstream);
 #endif
-		if (ret==NULL) return NULL;
+	if (ret==NULL) return NULL;
 
-		result = calloc(1, strlen(ret->d_name) + 1);
-		if (result == NULL) {
-			return NULL;
-		}
-		strcpy(result, ret->d_name);
-#ifdef DT_REG
+	result = calloc(1, strlen(ret->d_name) + 1);
+	if (result == NULL) {
+		return NULL;
 	}
-	while ((ret->d_type != DT_REG) && (ret->d_type != DT_UNKNOWN)
-	       && (ret != NULL));
-#endif
+	strcpy(result, ret->d_name);
 
 	return result;
 
