@@ -1,6 +1,6 @@
 /* panama_x.c */
 
-/* $Id: panama.c,v 1.18 2002/03/09 20:29:04 nmav Exp $ */
+/* $Id: panama.c,v 1.19 2002/05/24 06:15:00 nmav Exp $ */
 
 /* daemen.j@protonworld.com */
 /**************************************************************************+
@@ -518,24 +518,16 @@ WIN32DLL_DEFINE
     int _mcrypt_set_key(PANAMA_KEY * pan_key, char *in_key, int keysize,
 			char *init_vec, int vecsize)
 {
-	char *key;
+	byte key[32];
 	int keyblocks = (8 * keysize) / (PAN_STAGE_SIZE * WORDLENGTH);
 	int vecblocks = (8 * vecsize) / (PAN_STAGE_SIZE * WORDLENGTH);
-#ifdef WORDS_BIGENDIAN
 	int i;
 
-	key = calloc(1, 32);
-	if (key == NULL)
-		return -1;
-
-	memmove(key, in_key, keysize);
-#else
-	key = in_key;
-#endif
+	pan_key->keymat = (void*) pan_key->wkeymat;
 
 /* initialize the Panama state machine for a fresh crypting operation */
 	pan_reset(&pan_key->buffer, &pan_key->state);
-	pan_push((void *) key, keyblocks, &pan_key->buffer,
+	pan_push((void *) in_key, keyblocks, &pan_key->buffer,
 		 &pan_key->state);
 	if (init_vec != NULL)
 		pan_push((void *) init_vec, vecblocks, &pan_key->buffer,
@@ -543,17 +535,16 @@ WIN32DLL_DEFINE
 
 	pan_pull(NULL, NULL, 32, &pan_key->buffer, &pan_key->state);
 
-	pan_pull(NULL, (void *) &pan_key->keymat, 1, &pan_key->buffer,
+	pan_pull(NULL, pan_key->wkeymat, 1, &pan_key->buffer,
 		 &pan_key->state);
 	pan_key->keymat_pointer = 0;
+
 #ifdef WORDS_BIGENDIAN
 	for (i = 0; i < 8; i++) {
 
-		((word32 *) pan_key->keymat)[i] =
-		    byteswap32(((word32 *) pan_key->keymat)[i]);
+		pan_key->wkeymat[i] =
+		    byteswap32( pan_key->wkeymat[i]);
 	}
-	memset( key, 0, 32);
-	free(key);
 #endif
 
 	return 0;
@@ -572,14 +563,13 @@ WIN32DLL_DEFINE void _mcrypt_encrypt(PANAMA_KEY * pan_key,	/* the key from pan_i
 	for (i = 0; i < length; i++) {
 
 		if (pan_key->keymat_pointer == 32) {
-			pan_pull(NULL, (void *) &pan_key->keymat, 1,
+			pan_pull(NULL, (void *) pan_key->wkeymat, 1,
 				 &pan_key->buffer, &pan_key->state);
 			pan_key->keymat_pointer = 0;
 #ifdef WORDS_BIGENDIAN
 			for (j = 0; j < 8; j++) {
-				((word32 *) pan_key->keymat)[j] =
-				    byteswap32(((word32 *) pan_key->keymat)
-					       [j]);
+				pan_key->wkeymat[j] =
+				    byteswap32( pan_key->wkeymat[j]);
 			}
 #endif
 		}
