@@ -20,7 +20,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: twofish.c,v 1.13 2002/03/09 20:29:04 nmav Exp $ */
+/* $Id: twofish.c,v 1.14 2002/05/26 11:15:05 nmav Exp $ */
 
 /* Timing data for Twofish (twofish.c)
 
@@ -612,38 +612,28 @@ WIN32DLL_DEFINE const char *_mcrypt_get_algorithms_name()
 return "Twofish";
 }
 
-#define CIPHER "cc1c778374bccd6e73bfc642384cef7d"
+#define CIPHER "019f9809de1711858faac3a3ba20fbc3"
+#define PT "\xD4\x91\xDB\x16\xE7\xB1\xC3\x9E\x86\xCB\x08\x6B\x78\x9F\x54\x19"
+#define KEY "\x9F\x58\x9F\x5C\xF6\x12\x2C\x32\xB6\xBF\xEC\x2F\x2A\xE8\xC3\x5A"
 
 WIN32DLL_DEFINE int _mcrypt_self_test()
 {
-	char *keyword;
+	unsigned char keyword[16];
 	unsigned char plaintext[16];
 	unsigned char ciphertext[16];
 	int blocksize = _mcrypt_get_block_size(), j;
-	void *key;
+	void* key;
 	unsigned char cipher_tmp[200];
 
-	keyword = calloc(1, _mcrypt_get_key_size());
-	if (keyword == NULL)
-		return -1;
+	memcpy( keyword, KEY, 16);
+	memcpy( plaintext, PT, 16);
 
-	for (j = 0; j < _mcrypt_get_key_size(); j++) {
-		keyword[j] = (j * 2 + 10) % 256;
-	}
-
-	for (j = 0; j < blocksize; j++) {
-		plaintext[j] = j % 256;
-	}
-	key = malloc(_mcrypt_get_size());
-	if (key == NULL) {
-		free( keyword);
-		return -1;
-	}
+	memcpy(ciphertext, plaintext, 16);
 	
-	memcpy(ciphertext, plaintext, blocksize);
-
-	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size());
-	free(keyword);
+	key = malloc(_mcrypt_get_size());
+	if (key==NULL) return -1;
+	
+	_mcrypt_set_key(key, (void *) keyword, 16);
 
 	_mcrypt_encrypt(key, (void *) ciphertext);
 
@@ -662,7 +652,7 @@ WIN32DLL_DEFINE int _mcrypt_self_test()
 	_mcrypt_decrypt(key, (void *) ciphertext);
 	free(key);
 
-	if (strcmp(ciphertext, plaintext) != 0) {
+	if (memcmp(ciphertext, plaintext, 16) != 0) {
 		printf("failed internally\n");
 		return -1;
 	}
